<!-- Generated by documentation.js. Update this documentation by updating the source code. -->

### Table of Contents

-   [combinedUpdaters][1]
    -   [addDataToMapUpdater][3]
    -   [updateVisDataUpdater][5]

## combinedUpdaters

Some actions will affect the entire kepler.lg instance state.
The updaters for these actions is exported as `combinedUpdaters`. These updater take the entire instance state
as the first argument. Read more about [Using updaters][7]

**Examples**

```javascript
import keplerGlReducer, {combinedUpdaters} from 'kepler.gl/reducers';
// Root Reducer
const reducers = combineReducers({
 keplerGl: keplerGlReducer,
 app: appReducer
});

const composedReducer = (state, action) => {
 switch (action.type) {
   // add data to map after receiving data from remote sources
   case 'LOAD_REMOTE_RESOURCE_SUCCESS':
     return {
       ...state,
       keplerGl: {
         ...state.keplerGl,
         // pass in kepler.gl instance state to combinedUpdaters
         map:  combinedUpdaters.addDataToMapUpdater(
          state.keplerGl.map,
          {
            payload: {
              datasets: action.datasets,
              options: {readOnly: true},
              config: action.config
             }
           }
         )
       }
     };
 }
 return reducers(state, action);
};

export default composedReducer;
```

### addDataToMapUpdater

Combine data and full configuration update in a single action

-   **Action**: [`addDataToMap`][8]

**Parameters**

-   `state` **[Object][9]** kepler.gl instance state, containing all subreducer state
-   `action` **[Object][9]** 
    -   `action.payload` **[Object][9]** `{datasets, options, config}`
        -   `action.payload.datasets` **([Array][10]&lt;[Object][9]> | [Object][9])** **\*required** datasets can be a dataset or an array of datasets
            Each dataset object needs to have `info` and `data` property.
            -   `action.payload.datasets.info` **[Object][9]** \-info of a dataset
                -   `action.payload.datasets.info.id` **[string][11]** id of this dataset. If config is defined, `id` should matches the `dataId` in config.
                -   `action.payload.datasets.info.label` **[string][11]** A display name of this dataset
            -   `action.payload.datasets.data` **[Object][9]** **\*required** The data object, in a tabular format with 2 properties `fields` and `rows`
                -   `action.payload.datasets.data.fields` **[Array][10]&lt;[Object][9]>** **\*required** Array of fields,
                    -   `action.payload.datasets.data.fields.name` **[string][11]** **\*required** Name of the field,
                -   `action.payload.datasets.data.rows` **[Array][10]&lt;[Array][10]>** **\*required** Array of rows, in a tabular format with `fields` and `rows`
        -   `action.payload.options` **[Object][9]** option object `{centerMap: true}`
        -   `action.payload.config` **[Object][9]** map config

Returns **[Object][9]** nextState

### updateVisDataUpdater

Apply data and config to visState reducer

-   **Action**: [`updateVisData`][12]

**Parameters**

-   `state` **[Object][9]** kepler.gl instance state, containing all subreducer state
-   `action` **[Object][9]** 
    -   `action.datasets` **([Array][10]&lt;[Object][9]> | [Object][9])** **\*required** datasets can be a dataset or an array of datasets
        Each dataset object needs to have `info` and `data` property.
        -   `action.datasets.info` **[Object][9]** \-info of a dataset
            -   `action.datasets.info.id` **[string][11]** id of this dataset. If config is defined, `id` should matches the `dataId` in config.
            -   `action.datasets.info.label` **[string][11]** A display name of this dataset
        -   `action.datasets.data` **[Object][9]** **\*required** The data object, in a tabular format with 2 properties `fields` and `rows`
            -   `action.datasets.data.fields` **[Array][10]&lt;[Object][9]>** **\*required** Array of fields,
                -   `action.datasets.data.fields.name` **[string][11]** **\*required** Name of the field,
            -   `action.datasets.data.rows` **[Array][10]&lt;[Array][10]>** **\*required** Array of rows, in a tabular format with `fields` and `rows`
    -   `action.options` **[Object][9]** 
        -   `action.options.centerMap` **[Boolean][13]** 
        -   `action.options.readOnly` **[Boolean][13]** 
    -   `action.config` **[Object][9]** 

Returns **[Object][9]** nextState

[1]: #combinedupdaters

[2]: #examples

[3]: #adddatatomapupdater

[4]: #parameters

[5]: #updatevisdataupdater

[6]: #parameters-1

[7]: ../advanced-usage/using-updaters.md

[8]: ../actions/actions.md#adddatatomap

[9]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object

[10]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Array

[11]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String

[12]: ../actions/actions.md#updatevisdata

[13]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Boolean
