<!-- Generated by documentation.js. Update this documentation by updating the source code. -->

### Table of Contents

-   [mapStateUpdaters][1]
    -   [fitBoundsUpdater][3]
    -   [INITIAL_MAP_STATE][5]
    -   [receiveMapConfigUpdater][7]
    -   [togglePerspectiveUpdater][9]
    -   [toggleSplitMapUpdater][11]
    -   [updateMapUpdater][13]

## mapStateUpdaters

Updaters for `mapState` reducer. Can be used in your root reducer to directly modify kepler.gl's state.
Read more about [Using updaters][15]

**Examples**

```javascript
import keplerGlReducer, {mapStateUpdaters} from 'kepler.gl/reducers';
// Root Reducer
const reducers = combineReducers({
 keplerGl: keplerGlReducer,
 app: appReducer
});

const composedReducer = (state, action) => {
 switch (action.type) {
   // click button to close side panel
   case 'CLICK_BUTTON':
     return {
       ...state,
       keplerGl: {
         ...state.keplerGl,
         foo: {
            ...state.keplerGl.foo,
            mapState: mapStateUpdaters.fitBoundsUpdater(
              mapState, {payload: [127.34, 31.09, 127.56, 31.59]]}
            )
         }
       }
     };
 }
 return reducers(state, action);
};

export default composedReducer;
```

### fitBoundsUpdater

Fit map viewport to bounds

-   **Action**: [`fitBounds`][16]

**Parameters**

-   `state` **[Object][17]** 
-   `action` **[Object][17]** 
    -   `action.payload` **[Array][18]&lt;[number][19]>** bounds as `[lngMin, latMin, lngMax, latMax]`

Returns **[Object][17]** nextState

### INITIAL_MAP_STATE

Default initial `mapState`

#### Properties

-   `pitch` **[number][19]** Default: `0`
-   `bearing` **[number][19]** Default: `0`
-   `latitude` **[number][19]** Default: `37.75043`
-   `longitude` **[number][19]** Default: `-122.34679`
-   `zoom` **[number][19]** Default: `9`
-   `dragRotate` **[boolean][20]** Default: `false`
-   `width` **[number][19]** Default: `800`
-   `height` **[number][19]** Default: `800`
-   `isSplit` **[boolean][20]** Default: `false`

### receiveMapConfigUpdater

Update `mapState` to propagate a new config

-   **Action**: [`receiveMapConfig`][21]

**Parameters**

-   `state` **[Object][17]** 
-   `action` **[Object][17]** 
    -   `action.payload` **[Object][17]** saved map config

Returns **[Object][17]** nextState

### togglePerspectiveUpdater

Toggle between 3d and 2d map.

-   **Action**: [`togglePerspective`][22]

**Parameters**

-   `state` **[Object][17]** 

Returns **[Object][17]** nextState

### toggleSplitMapUpdater

Toggle between one or split maps

-   **Action**: [`toggleSplitMap`][23]

**Parameters**

-   `state` **[Object][17]** 

Returns **[Object][17]** nextState

### updateMapUpdater

Update map viewport

-   **Action**: [`updateMap`][24]

**Parameters**

-   `state` **[Object][17]** 
-   `action` **[Object][17]** 
    -   `action.payload` **[Object][17]** viewport

Returns **[Object][17]** nextState

[1]: #mapstateupdaters

[2]: #examples

[3]: #fitboundsupdater

[4]: #parameters

[5]: #initial_map_state

[6]: #properties

[7]: #receivemapconfigupdater

[8]: #parameters-1

[9]: #toggleperspectiveupdater

[10]: #parameters-2

[11]: #togglesplitmapupdater

[12]: #parameters-3

[13]: #updatemapupdater

[14]: #parameters-4

[15]: ../advanced-usage/using-updaters.md

[16]: ../actions/actions.md#fitbounds

[17]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object

[18]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Array

[19]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Number

[20]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Boolean

[21]: ../actions/actions.md#receivemapconfig

[22]: ../actions/actions.md#toggleperspective

[23]: ../actions/actions.md#togglesplitmap

[24]: ../actions/actions.md#updatemap
