<!-- Generated by documentation.js. Update this documentation by updating the source code. -->

### Table of Contents

-   [visStateUpdaters][1]
    -   [addFilterUpdater][3]
    -   [addLayerUpdater][5]
    -   [enlargeFilterUpdater][7]
    -   [INITIAL_VIS_STATE][9]
    -   [interactionConfigChangeUpdater][11]
    -   [layerClickUpdater][13]
    -   [layerHoverUpdater][15]
    -   [layerTypeChangeUpdater][17]
    -   [layerVisConfigChangeUpdater][19]
    -   [layerVisualChannelChangeUpdater][21]
    -   [loadFilesErrUpdater][23]
    -   [loadFilesUpdater][25]
    -   [mapClickUpdater][27]
    -   [receiveMapConfigUpdater][29]
    -   [removeDatasetUpdater][31]
    -   [removeFilterUpdater][33]
    -   [removeLayerUpdater][35]
    -   [reorderLayerUpdater][37]
    -   [resetMapConfigVisStateUpdater][39]
    -   [setFilterPlotUpdater][41]
    -   [setFilterUpdater][43]
    -   [setVisibleLayersForMapUpdater][45]
    -   [showDatasetTableUpdater][47]
    -   [toggleFilterAnimationUpdater][49]
    -   [toggleLayerForMapUpdater][51]
    -   [toggleSplitMapUpdater][53]
    -   [updateAnimationSpeedUpdater][55]
    -   [updateLayerBlendingUpdater][57]
    -   [updateVisDataUpdater][59]

## visStateUpdaters

Updaters for `visState` reducer. Can be used in your root reducer to directly modify kepler.gl's state.
Read more about [Using updaters][61]

**Examples**

```javascript
import keplerGlReducer, {visStateUpdaters} from 'kepler.gl/reducers';
// Root Reducer
const reducers = combineReducers({
 keplerGl: keplerGlReducer,
 app: appReducer
});

const composedReducer = (state, action) => {
 switch (action.type) {
   case 'CLICK_BUTTON':
     return {
       ...state,
       keplerGl: {
         ...state.keplerGl,
         foo: {
            ...state.keplerGl.foo,
            visState: visStateUpdaters.enlargeFilterUpdater(
              state.keplerGl.foo.visState,
              {idx: 0}
            )
         }
       }
     };
 }
 return reducers(state, action);
};

export default composedReducer;
```

### addFilterUpdater

Add a new filter

-   **Action**: [`addFilter`][62]

**Parameters**

-   `state` **[Object][63]** `visState`
-   `action` **[Object][63]** action
    -   `action.dataId` **[string][64]** dataset `id` this new filter is associated with

Returns **[Object][63]** nextState

### addLayerUpdater

Add a new layer

-   **Action**: [`addLayer`][65]

**Parameters**

-   `state` **[Object][63]** `visState`
-   `action` **[Object][63]** action
    -   `action.props` **[Object][63]** new layer props

Returns **[Object][63]** nextState

### enlargeFilterUpdater

Show larger time filter at bottom for time playback (apply to time filter only)

-   **Action**: [`enlargeFilter`][66]

**Parameters**

-   `state` **[Object][63]** `visState`
-   `action` **[Object][63]** action
    -   `action.idx` **[Number][67]** index of filter to enlarge

Returns **[Object][63]** nextState

### INITIAL_VIS_STATE

Default initial `visState`

Type: [Object][63]

#### Properties

-   `layers` **[Array][68]** 
-   `layerData` **[Array][68]** 
-   `layerToBeMerged` **[Array][68]** 
-   `layerOrder` **[Array][68]** 
-   `filters` **[Array][68]** 
-   `filterToBeMerged` **[Array][68]** 
-   `datasets` **[Array][68]** 
-   `editingDataset` **[string][64]** 
-   `interactionConfig` **[Object][63]** 
-   `interactionToBeMerged` **[Object][63]** 
-   `layerBlending` **[string][64]** 
-   `hoverInfo` **[Object][63]** 
-   `clicked` **[Object][63]** 
-   `fileLoading` **[boolean][69]** 
-   `fileLoadingErr` **any** 
-   `splitMaps` **[Array][68]** a list of objects of layer availabilities and visibilities for each map

### interactionConfigChangeUpdater

Update `interactionConfig`

-   **Action**: [`interactionConfigChange`][70]

**Parameters**

-   `state` **[Object][63]** `visState`
-   `action` **[Object][63]** action
    -   `action.config` **[Object][63]** new config as key value map: `{tooltip: {enabled: true}}`

Returns **[Object][63]** nextState

### layerClickUpdater

Trigger layer click event with clicked object

-   **Action**: [`onLayerClick`][71]

**Parameters**

-   `state` **[Object][63]** `visState`
-   `action` **[Object][63]** action
    -   `action.info` **[Object][63]** Object clicked, returned by deck.gl

Returns **[Object][63]** nextState

### layerHoverUpdater

Trigger layer hover event with hovered object

-   **Action**: [`onLayerHover`][72]

**Parameters**

-   `state` **[Object][63]** `visState`
-   `action` **[Object][63]** action
    -   `action.info` **[Object][63]** Object hovered, returned by deck.gl

Returns **[Object][63]** nextState

### layerTypeChangeUpdater

Update layer type. Previews layer config will be copied if applicable.

-   **Action**: [`layerTypeChange`][73]

**Parameters**

-   `state` **[Object][63]** `visState`
-   `action` **[Object][63]** action
    -   `action.oldLayer` **[Object][63]** layer to be updated
    -   `action.newType` **[string][64]** new type

Returns **[Object][63]** nextState

### layerVisConfigChangeUpdater

Update layer `visConfig`

-   **Action**: [`layerVisConfigChange`][74]

**Parameters**

-   `state` **[Object][63]** `visState`
-   `action` **[Object][63]** action
    -   `action.oldLayer` **[Object][63]** layer to be updated
    -   `action.newVisConfig` **[Object][63]** new visConfig as a key value map: e.g. `{opacity: 0.8}`

Returns **[Object][63]** nextState

### layerVisualChannelChangeUpdater

Update layer visual channel

-   **Action**: [`layerVisualChannelConfigChange`][75]

**Parameters**

-   `state` **[Object][63]** `visState`
-   `action` **[Object][63]** action
    -   `action.oldLayer` **[Object][63]** layer to be updated
    -   `action.newConfig` **[Object][63]** new visual channel config
    -   `action.channel` **[string][64]** channel to be updated

Returns **[Object][63]** nextState

### loadFilesErrUpdater

Trigger loading file error

-   **Action**: [`loadFilesErr`][76]

**Parameters**

-   `state` **[Object][63]** `visState`
-   `action` **[Object][63]** action
    -   `action.error` **any** 

Returns **[Object][63]** nextState

### loadFilesUpdater

Trigger file loading dispatch `addDataToMap` if succeed, or `loadFilesErr` if failed

-   **Action**: [`loadFiles`][77]

**Parameters**

-   `state` **[Object][63]** `visState`
-   `action` **[Object][63]** action
    -   `action.files` **[Array][68]&lt;[Object][63]>** array of fileblob

Returns **[Object][63]** nextState

### mapClickUpdater

Trigger map click event, unselect clicked object

-   **Action**: [`onMapClick`][78]

**Parameters**

-   `state` **[Object][63]** `visState`

Returns **[Object][63]** nextState

### receiveMapConfigUpdater

Propagate `visState` reducer with a new configuration. Current config will be override.

-   **Action**: [`receiveMapConfig`][79]

**Parameters**

-   `state` **[Object][63]** `visState`
-   `action` **[Object][63]** action
    -   `action.payload` **[Object][63]** map config to be propagated

Returns **[Object][63]** nextState

### removeDatasetUpdater

Remove a dataset and all layers, filters, tooltip configs that based on it

-   **Action**: [`removeDataset`][80]

**Parameters**

-   `state` **[Object][63]** `visState`
-   `action` **[Object][63]** action
    -   `action.key` **[string][64]** dataset id

Returns **[Object][63]** nextState

### removeFilterUpdater

Remove a filter

-   **Action**: [`removeFilter`][81]

**Parameters**

-   `state` **[Object][63]** `visState`
-   `action` **[Object][63]** action
    -   `action.idx` **[Number][67]** index of filter to b e removed

Returns **[Object][63]** nextState

### removeLayerUpdater

remove layer

-   **Action**: [`removeLayer`][82]

**Parameters**

-   `state` **[Object][63]** `visState`
-   `action` **[Object][63]** action
    -   `action.idx` **[Number][67]** index of layer to b e removed

Returns **[Object][63]** nextState

### reorderLayerUpdater

Reorder layer

-   **Action**: [`reorderLayer`][83]

**Parameters**

-   `state` **[Object][63]** `visState`
-   `action` **[Object][63]** action
    -   `action.order` **[Array][68]&lt;[Number][67]>** an array of layer indexes

Returns **[Object][63]** nextState

### resetMapConfigVisStateUpdater

reset visState to initial State

-   **Action**: [`resetMapConfig`][84]

**Parameters**

-   `state` **[Object][63]** `visState`

Returns **[Object][63]** nextState

### setFilterPlotUpdater

Set the property of a filter plot

-   **Action**: [`setFilterPlot`][85]

**Parameters**

-   `state` **[Object][63]** `visState`
-   `action` **[Object][63]** action
    -   `action.idx` **[Number][67]** 
    -   `action.newProp` **[Object][63]** key value mapping of new prop `{yAxis: 'histogram'}`

Returns **[Object][63]** nextState

### setFilterUpdater

Update filter property

-   **Action**: [`setFilter`][86]

**Parameters**

-   `state` **[Object][63]** `visState`
-   `action` **[Object][63]** action
    -   `action.idx` **[Number][67]** `idx` of filter to be updated
    -   `action.prop` **[string][64]** `prop` of filter, e,g, `dataId`, `name`, `value`
    -   `action.value` **any** new value

Returns **[Object][63]** nextState

### setVisibleLayersForMapUpdater

Set layers to be visible in split map

-   **Action**: [`setVisibleLayersForMap`][87]

**Parameters**

-   `state` **[Object][63]** `visState`
-   `action` **[Object][63]** action
-   `mapIndex` **[Number][67]** index of the split map
-   `layerIds` **[Array][68]&lt;[string][64]>** array of layer ids

Returns **[Object][63]** nextState

### showDatasetTableUpdater

Display dataset table in a modal

-   **Action**: [`showDatasetTable`][88]

**Parameters**

-   `state` **[Object][63]** `visState`
-   `action` **[Object][63]** action
    -   `action.dataId` **[string][64]** dataset id to show in table

Returns **[Object][63]** nextState

### toggleFilterAnimationUpdater

Start and end filter animation

-   **Action**: [`toggleAnimation`][89]

**Parameters**

-   `state` **[Object][63]** `visState`
-   `action` **[Object][63]** action
    -   `action.idx` **[Number][67]** idx of filter

Returns **[Object][63]** nextState

### toggleLayerForMapUpdater

Toggle visibility of a layer in a split map

-   **Action**: [`toggleLayerForMap`][90]

**Parameters**

-   `state` **[Object][63]** 
-   `action` **[Object][63]** 
    -   `action.mapIndex` **[Number][67]** index of the split map
    -   `action.layerId` **[string][64]** id of the layer

Returns **[Object][63]** nextState

### toggleSplitMapUpdater

Toggle visibility of a layer for a split map

-   **Action**: [`toggleSplitMap`][91]

**Parameters**

-   `state` **[Object][63]** `visState`
-   `action` **[Object][63]** action
    -   `action.payload` **([Number][67] \| [undefined][92])** index of the split map

Returns **[Object][63]** nextState

### updateAnimationSpeedUpdater

Change filter animation speed

-   **Action**: [`updateAnimationSpeed`][93]

**Parameters**

-   `state` **[Object][63]** `visState`
-   `action` **[Object][63]** action
    -   `action.idx` **[Number][67]** `idx` of filter
    -   `action.speed` **[Number][67]** `speed` to change it to. `speed` is a multiplier

Returns **[Object][63]** nextState

### updateLayerBlendingUpdater

update layer blending mode

-   **Action**: [`updateLayerBlending`][94]

**Parameters**

-   `state` **[Object][63]** `visState`
-   `action` **[Object][63]** action
    -   `action.mode` **[string][64]** one of `additive`, `normal` and `subtractive`

Returns **[Object][63]** nextState

### updateVisDataUpdater

Add new dataset to `visState`, with option to load a map config along with the datasets

-   **Action**: [`updateVisData`][95]

**Parameters**

-   `state` **[Object][63]** `visState`
-   `action` **[Object][63]** action
    -   `action.datasets` **([Array][68]&lt;[Object][63]> | [Object][63])** **\*required** datasets can be a dataset or an array of datasets
        Each dataset object needs to have `info` and `data` property.
        -   `action.datasets.info` **[Object][63]** \-info of a dataset
            -   `action.datasets.info.id` **[string][64]** id of this dataset. If config is defined, `id` should matches the `dataId` in config.
            -   `action.datasets.info.label` **[string][64]** A display name of this dataset
        -   `action.datasets.data` **[Object][63]** **\*required** The data object, in a tabular format with 2 properties `fields` and `rows`
            -   `action.datasets.data.fields` **[Array][68]&lt;[Object][63]>** **\*required** Array of fields,
                -   `action.datasets.data.fields.name` **[string][64]** **\*required** Name of the field,
            -   `action.datasets.data.rows` **[Array][68]&lt;[Array][68]>** **\*required** Array of rows, in a tabular format with `fields` and `rows`
    -   `action.options` **[Object][63]** option object `{centerMap: true}`
    -   `action.config` **[Object][63]** map config

Returns **[Object][63]** nextState

[1]: #visstateupdaters

[2]: #examples

[3]: #addfilterupdater

[4]: #parameters

[5]: #addlayerupdater

[6]: #parameters-1

[7]: #enlargefilterupdater

[8]: #parameters-2

[9]: #initial_vis_state

[10]: #properties

[11]: #interactionconfigchangeupdater

[12]: #parameters-3

[13]: #layerclickupdater

[14]: #parameters-4

[15]: #layerhoverupdater

[16]: #parameters-5

[17]: #layertypechangeupdater

[18]: #parameters-6

[19]: #layervisconfigchangeupdater

[20]: #parameters-7

[21]: #layervisualchannelchangeupdater

[22]: #parameters-8

[23]: #loadfileserrupdater

[24]: #parameters-9

[25]: #loadfilesupdater

[26]: #parameters-10

[27]: #mapclickupdater

[28]: #parameters-11

[29]: #receivemapconfigupdater

[30]: #parameters-12

[31]: #removedatasetupdater

[32]: #parameters-13

[33]: #removefilterupdater

[34]: #parameters-14

[35]: #removelayerupdater

[36]: #parameters-15

[37]: #reorderlayerupdater

[38]: #parameters-16

[39]: #resetmapconfigvisstateupdater

[40]: #parameters-17

[41]: #setfilterplotupdater

[42]: #parameters-18

[43]: #setfilterupdater

[44]: #parameters-19

[45]: #setvisiblelayersformapupdater

[46]: #parameters-20

[47]: #showdatasettableupdater

[48]: #parameters-21

[49]: #togglefilteranimationupdater

[50]: #parameters-22

[51]: #togglelayerformapupdater

[52]: #parameters-23

[53]: #togglesplitmapupdater

[54]: #parameters-24

[55]: #updateanimationspeedupdater

[56]: #parameters-25

[57]: #updatelayerblendingupdater

[58]: #parameters-26

[59]: #updatevisdataupdater

[60]: #parameters-27

[61]: ../advanced-usage/using-updaters.md

[62]: ../actions/actions.md#addfilter

[63]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object

[64]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String

[65]: ../actions/actions.md#addlayer

[66]: ../actions/actions.md#enlargefilter

[67]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Number

[68]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Array

[69]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Boolean

[70]: ../actions/actions.md#interactionconfigchange

[71]: ../actions/actions.md#onlayerclick

[72]: ../actions/actions.md#onlayerhover

[73]: ../actions/actions.md#layertypechange

[74]: ../actions/actions.md#layervisconfigchange

[75]: ../actions/actions.md#layervisualchannelconfigchange

[76]: ../actions/actions.md#loadfileserr

[77]: ../actions/actions.md#loadfiles

[78]: ../actions/actions.md#onmapclick

[79]: ../actions/actions.md#receivemapconfig

[80]: ../actions/actions.md#removedataset

[81]: ../actions/actions.md#removefilter

[82]: ../actions/actions.md#removelayer

[83]: ../actions/actions.md#reorderlayer

[84]: ../actions/actions.md#resetmapconfig

[85]: ../actions/actions.md#setfilterplot

[86]: ../actions/actions.md#setfilter

[87]: ../actions/actions.md#setvisiblelayersformap

[88]: ../actions/actions.md#showdatasettable

[89]: ../actions/actions.md#toggleanimation

[90]: ../actions/actions.md#togglelayerformap

[91]: ../actions/actions.md#togglesplitmap

[92]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/undefined

[93]: ../actions/actions.md#updateanimationspeed

[94]: ../actions/actions.md#updatelayerblending

[95]: ../actions/actions.md#updatevisdata
